"""autoplay-sdk — real-time event streaming client for Autoplay connectors."""

from autoplay_sdk.async_client import AsyncConnectorClient
from autoplay_sdk.buffer import BufferBackend, EventBuffer, RedisEventBuffer
from autoplay_sdk.client import ConnectorClient
from autoplay_sdk.context_store import AsyncContextStore, ContextStore
from autoplay_sdk.models import ActionsPayload, AnyPayload, SlimAction, SummaryPayload
from autoplay_sdk.rag import AsyncRagPipeline, RagPipeline
from autoplay_sdk.summarizer import (
    DEFAULT_PROMPT,
    AsyncSessionSummarizer,
    SessionSummarizer,
)
from autoplay_sdk.webhook_receiver import WebhookReceiver

__all__ = [
    # Clients
    "ConnectorClient",
    "AsyncConnectorClient",
    # Typed models
    "ActionsPayload",
    "SummaryPayload",
    "SlimAction",
    "AnyPayload",
    # Buffer
    "EventBuffer",
    "RedisEventBuffer",
    "BufferBackend",
    # Context store (query-time RAG enrichment)
    "ContextStore",
    "AsyncContextStore",
    # RAG pipeline (upsert flow)
    "RagPipeline",
    "AsyncRagPipeline",
    # Summarizer
    "SessionSummarizer",
    "AsyncSessionSummarizer",
    "DEFAULT_PROMPT",
    # Push webhook receiver
    "WebhookReceiver",
    # Version
    "__version__",
]
__version__ = "0.3.0"
